@@ -30,9 +30,13 @@ MIN_LINE_LENGTH = int(os.getenv('CHECKOV_MIN_LINE_LENGTH', '5'))
 
 
 @lru_cache(maxsize=1)
-def read_raw_lines(filename: str) -> List[str]:
-    with open(filename) as f:
-        return f.readlines()
+def read_raw_lines(file_name: str) -> List[str]:
+    try:
+        with open(file_name) as f:
+            return f.readlines()
+    except IOError:
+        log.debug(f"Can't open file {file_name}")
+        return []
 
 
 def get_files_to_scan(
@@ -341,6 +345,10 @@ def _process_line_based_plugins(
             lines=line_content,
             line_number=line_number,
         )
+        raw_code_snippet = get_code_snippet(
+            lines=read_raw_lines(filename),
+            line_number=line_number,
+        )
 
         # We apply line-specific filters, and see whether that allows us to quit early.
         if _is_filtered_out(
@@ -351,27 +359,26 @@ def _process_line_based_plugins(
         ):
             continue
 
-        yield from (
-            secret
-            for plugin in get_plugins()
+        for plugin in get_plugins():
             for secret in _scan_line(
-                plugin=plugin,
-                filename=filename,
-                line=line,
-                line_number=line_number,
-                context=code_snippet,
-                is_added=is_added,
-                is_removed=is_removed,
-            )
-            if not _is_filtered_out(
-                required_filter_parameters=['context'],
-                filename=secret.filename,
-                secret=secret.secret_value,
-                plugin=plugin,
-                line=line,
-                context=code_snippet,
-            )
-        )
+                    plugin=plugin,
+                    filename=filename,
+                    line=line,
+                    line_number=line_number,
+                    context=code_snippet,
+                    raw_context=raw_code_snippet,
+            ):
+                secret.is_removed = is_removed
+                secret.is_added = is_added
+                if not _is_filtered_out(
+                        required_filter_parameters=['context'],
+                        filename=secret.filename,
+                        secret=secret.secret_value,
+                        plugin=plugin,
+                        line=line,
+                        context=code_snippet,
+                ):
+                    yield secret
 
 
 def _scan_line(
