@@ -52,8 +52,6 @@ class BasePlugin(metaclass=ABCMeta):
             line_number: int = 0,
             context: CodeSnippet | None = None,
             raw_context: CodeSnippet | None = None,
-            is_added: bool = False,
-            is_removed: bool = False,
             **kwargs: Any
     ) -> Set[PotentialSecret]:
         """This examines a line and finds all possible secret values in it."""
@@ -84,8 +82,6 @@ class BasePlugin(metaclass=ABCMeta):
                     secret=match,
                     line_number=line_number,
                     is_verified=is_verified,
-                    is_added=is_added,
-                    is_removed=is_removed,
                 ),
             )
 
